import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BMIApp()
        }
    }
}

@Composable
fun BMIApp() {
    MaterialTheme {
        Surface(modifier = Modifier.fillMaxSize()) {
            BMICalculator()
        }
    }
}

@Composable
fun BMICalculator() {
    var heightInput by remember { mutableStateOf("") }
    var weightInput by remember { mutableStateOf("") }
    var bmiResult by remember { mutableStateOf<Double?>(null) }
    var category by remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        Text("BMI Calculator", fontSize = 24.sp, modifier = Modifier.padding(bottom = 16.dp))

        OutlinedTextField(
            value = heightInput,
            onValueChange = { heightInput = it },
            label = { Text("Height (cm)") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            modifier = Modifier.fillMaxWidth()
        )

        Spacer(modifier = Modifier.height(8.dp))

        OutlinedTextField(
            value = weightInput,
            onValueChange = { weightInput = it },
            label = { Text("Weight (kg)") },
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            modifier = Modifier.fillMaxWidth()
        )

        Spacer(modifier = Modifier.height(16.dp))

        Button(onClick = {
            val height = heightInput.toDoubleOrNull()?.div(100)
            val weight = weightInput.toDoubleOrNull()
            if (height != null && weight != null) {
                bmiResult = weight / (height * height)
                category = when {
                    bmiResult!! < 18.5 -> "Underweight"
                    bmiResult!! < 24.9 -> "Normal weight"
                    bmiResult!! < 29.9 -> "Overweight"
                    else -> "Obesity"
                }
            }
        }, modifier = Modifier.fillMaxWidth()) {
            Text("Calculate")
        }

        Spacer(modifier = Modifier.height(16.dp))

        bmiResult?.let {
            Text("Your BMI: %.2f".format(it), fontSize = 20.sp)
            Text("Category: $category", fontSize = 20.sp)
        }
    }
}
